@@ -17,7 +17,7 @@
 
 @protocol NSNumber
 
-- (char)charValue;
+- (signed char)charValue;
 - (unsigned char)unsignedCharValue;
 - (short)shortValue;
 - (unsigned short)unsignedShortValue;
